@@ -140,11 +140,14 @@ def one_label_sum(
 		sum_func(group["y_ls"])
 		for group in group_ls
 	]
+	# データ数のリストの作成
+	data_n_ls = [len(group["y_ls"]) for group in group_ls]
 	# データをパッケージングして返却
 	return {
 		"label": label,
 		"x": show_x_ls,
 		"y": show_y_ls,
+		"data_n": data_n_ls,
 	}
 
 # 分位点散布図の描画 [quantile_scatter]
